@@ -8,7 +8,7 @@
 #'
 #' To see details about functions which are internally used to carry out these
 #' analyses, see the following vignette-
-#' \url{https://indrajeetpatil.github.io/statsExpressions/articles/stats_details.html}
+#' <https://indrajeetpatil.github.io/statsExpressions/articles/stats_details.html>
 #'
 #' @param x The variable to use as the **rows** in the contingency table.
 #' @param y The variable to use as the **columns** in the contingency table.
@@ -41,15 +41,6 @@
 #' @inheritParams stats::chisq.test
 #' @inheritParams oneway_anova
 #'
-#' @importFrom BayesFactor contingencyTableBF logMeanExpLogs
-#' @importFrom dplyr pull select rename mutate
-#' @importFrom rlang enquo quo_is_null exec !!!
-#' @importFrom tidyr uncount drop_na
-#' @importFrom stats mcnemar.test chisq.test dmultinom rgamma
-#' @importFrom effectsize cramers_v cohens_g
-#' @importFrom parameters standardize_names
-#' @importFrom insight format_value
-#'
 #' @examples
 #' \donttest{
 #' # for reproducibility
@@ -114,84 +105,62 @@ contingency_table <- function(data,
                               ...) {
 
   # check the data contains needed column
-  type <- ipmisc::stats_type_switch(type)
+  type <- stats_type_switch(type)
 
   # one-way or two-way table?
-  test <- ifelse(!rlang::quo_is_null(rlang::enquo(y)), "two.way", "one.way")
+  test <- ifelse(!quo_is_null(enquo(y)), "2way", "1way")
 
   # creating a dataframe
   data %<>%
-    dplyr::select({{ x }}, {{ y }}, .counts = {{ counts }}) %>%
+    select({{ x }}, {{ y }}, .counts = {{ counts }}) %>%
     tidyr::drop_na(.)
 
   # untable the dataframe based on the count for each observation
   if (".counts" %in% names(data)) data %<>% tidyr::uncount(weights = .counts)
 
   # variables needed for both one-way and two-way analysis
-  x_vec <- data %>% dplyr::pull({{ x }})
+  x_vec <- data %>% pull({{ x }})
   if (is.null(ratio)) ratio <- rep(1 / length(table(x_vec)), length(table(x_vec)))
 
-  # ----------------------- non-Bayesian ---------------------------------------
+  # non-Bayesian ---------------------------------------
 
   if (type != "bayes") {
-    # default functions for analysis (only change for McNemar's test)
-    c(.f, .f.es) %<-% c(stats::chisq.test, effectsize::cramers_v)
+    # one-way table
+    if (test == "1way") .f.args <- list(x = table(x_vec), p = ratio, correct = FALSE)
+    if (test == "1way") c(.f, .f.es) %<-% c(stats::chisq.test, effectsize::pearsons_c)
+
+    # two-way table
+    if (test == "2way") .f.args <- list(x = table(data), correct = FALSE)
+    if (test == "2way" && paired) c(.f, .f.es) %<-% c(stats::mcnemar.test, effectsize::cohens_g)
+    if (test == "2way" && !paired) c(.f, .f.es) %<-% c(stats::chisq.test, effectsize::cramers_v)
 
     # Pearson's or McNemar's test
-    if (test == "two.way") {
-      if (isTRUE(paired)) c(.f, .f.es) %<-% c(stats::mcnemar.test, effectsize::cohens_g)
-      .f.args <- list(x = table(x_vec, data %>% dplyr::pull({{ y }})), correct = FALSE)
-    }
 
-    # goodness of fit test
-    if (test == "one.way") {
-      .f.args <- list(x = table(x_vec), p = ratio, correct = FALSE)
-      paired <- FALSE
-    }
-
-    # stats
-    stats_df <- tidy_model_parameters(rlang::exec(.f, !!!.f.args))
-
-    # computing effect size + CI
-    effsize_df <- rlang::exec(.f.es, adjust = TRUE, ci = conf.level, !!!.f.args) %>%
-      tidy_model_effectsize(.)
-
-    # combining dataframes
-    stats_df <- dplyr::bind_cols(stats_df, effsize_df)
-
-    # add expression column
-    stats_df %<>%
-      dplyr::mutate(
-        expression = list(expr_template(
-          data = .,
-          no.parameters = 1L,
-          n = nrow(data),
-          paired = paired,
-          k = k
-        ))
-      )
+    # combining dataframes: inferential stats + effect sizes
+    stats_df <- bind_cols(
+      tidy_model_parameters(exec(.f, !!!.f.args)),
+      tidy_model_effectsize(exec(.f.es, !!!.f.args, adjust = TRUE, ci = conf.level))
+    )
   }
 
-  # ----------------------- Bayesian ---------------------------------------
+  # Bayesian ---------------------------------------
 
   if (type == "bayes") {
     # two-way table
-    if (test == "two.way") {
-      # Bayes Factor object
-      bf_object <- BayesFactor::contingencyTableBF(
-        table(data %>% dplyr::pull({{ x }}), data %>% dplyr::pull({{ y }})),
+    if (test == "2way") {
+      # extract a tidy dataframe
+      stats_df <- BayesFactor::contingencyTableBF(
+        table(data),
         sampleType = sampling.plan,
         fixedMargin = fixed.margin,
         priorConcentration = prior.concentration
-      )
-
-      # Bayes Factor expression
-      stats_df <- bf_extractor(bf_object, conf.level, k = k, top.text = top.text)
+      ) %>%
+        tidy_model_parameters(ci = conf.level)
     }
 
     # one-way table
-    if (test == "one.way") {
-      xtab <- table(data %>% dplyr::pull({{ x }}))
+    if (test == "1way") {
+      xtab <- table(x_vec)
 
       # probability can't be exactly 0 or 1
       if (1 / length(as.vector(xtab)) == 0 || 1 / length(as.vector(xtab)) == 1) {
@@ -199,20 +168,20 @@ contingency_table <- function(data,
       }
 
       # use it
-      p1s <- rdirichlet_int(n = 100000, alpha = prior.concentration * ratio)
+      p1s <- rdirichlet(n = 100000L, alpha = prior.concentration * ratio)
 
       # prob
-      tmp_pr_h1 <- sapply(
+      pr_h1 <- sapply(
         X = 1:100000,
-        FUN = function(i) stats::dmultinom(x = as.matrix(xtab), prob = p1s[i, ], log = TRUE)
+        FUN = function(i) stats::dmultinom(as.matrix(xtab), prob = p1s[i, ], log = TRUE)
       )
 
       # BF = (log) prob of data under alternative - (log) prob of data under null
-      bf <- BayesFactor::logMeanExpLogs(tmp_pr_h1) -
-        stats::dmultinom(as.matrix(xtab), prob = ratio, log = TRUE)
-
       # computing Bayes Factor and formatting the results
-      stats_df <- tibble(bf10 = exp(bf), prior.scale = prior.concentration)
+      stats_df <- tibble(
+        bf10 = exp(BayesFactor::logMeanExpLogs(pr_h1) - stats::dmultinom(as.matrix(xtab), NULL, ratio, TRUE)),
+        prior.scale = prior.concentration
+      )
 
       # final expression
       expression <- substitute(
@@ -225,8 +194,8 @@ contingency_table <- function(data,
         ),
         env = list(
           top.text = top.text,
-          bf = format_value(-log(stats_df$bf10[[1]]), k),
-          a = format_value(stats_df$prior.scale[[1]], k)
+          bf = format_value(-log(stats_df$bf10), k),
+          a = format_value(stats_df$prior.scale, k)
         )
       )
 
@@ -234,10 +203,28 @@ contingency_table <- function(data,
       if (is.null(top.text)) expression <- expression$expr
 
       # computing Bayes Factor and formatting the results
-      stats_df %<>% dplyr::mutate(expression = list(expression))
+      stats_df %<>% mutate(expression = list(expression))
     }
   }
 
+  # expression ---------------------------------------
+
+  if (!(type == "bayes" && test == "1way")) {
+    stats_df %<>%
+      mutate(
+        expression = list(expr_template(
+          data = .,
+          no.parameters = 1L,
+          n = nrow(data),
+          paired = paired,
+          k = k,
+          top.text = top.text,
+          bayesian = ifelse(type == "bayes", TRUE, FALSE)
+        ))
+      ) %>%
+      polish_data()
+  }
+
   # return the output
   stats_df
 }
@@ -247,7 +234,7 @@ contingency_table <- function(data,
 #' @note `rdirichlet` function from `MCMCpack`
 #' @noRd
 
-rdirichlet_int <- function(n, alpha) {
+rdirichlet <- function(n, alpha) {
   l <- length(alpha)
   x <- matrix(stats::rgamma(l * n, alpha), ncol = l, byrow = TRUE)
   x / as.vector(x %*% rep(1, l))
