@@ -7,22 +7,21 @@ test_that(
 
     # subtitle
     set.seed(123)
-    df1 <-
-      two_sample_test(
-        type = "r",
-        data = dplyr::filter(
-          iris_long,
-          condition %in% c("Sepal.Length", "Sepal.Width")
-        ),
-        x = "condition",
-        y = value,
-        paired = TRUE,
-        k = 4
-      )
+    df1 <- two_sample_test(
+      type = "r",
+      data = filter(
+        iris_long,
+        condition %in% c("Sepal.Length", "Sepal.Width")
+      ),
+      x = condition,
+      y = value,
+      paired = TRUE,
+      k = 4
+    )
 
     # testing all details
     set.seed(123)
-    expect_snapshot(dplyr::select(df1, -expression))
+    expect_snapshot(select(df1, -expression))
     expect_snapshot(df1$expression[[1]])
   }
 )
@@ -32,19 +31,18 @@ test_that(
   code = {
     # subtitle
     set.seed(123)
-    df1 <-
-      two_sample_test(
-        type = "r",
-        data = dplyr::filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-        x = "condition",
-        y = desire,
-        paired = TRUE,
-        k = 3L
-      )
+    df1 <- two_sample_test(
+      type = "r",
+      data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+      x = condition,
+      y = desire,
+      paired = TRUE,
+      k = 3L
+    )
 
     # testing all details
     set.seed(123)
-    expect_snapshot(dplyr::select(df1, -expression))
+    expect_snapshot(select(df1, -expression))
     expect_snapshot(df1$expression[[1]])
   }
 )
@@ -57,20 +55,19 @@ test_that(
 
     # subtitle
     set.seed(123)
-    df1 <-
-      two_sample_test(
-        type = "r",
-        data = mtcars,
-        x = am,
-        y = "wt",
-        paired = FALSE,
-        conf.level = 0.99,
-        k = 3
-      )
+    df1 <- two_sample_test(
+      type = "r",
+      data = mtcars,
+      x = am,
+      y = wt,
+      paired = FALSE,
+      conf.level = 0.99,
+      k = 3
+    )
 
     # testing all details
     set.seed(123)
-    expect_snapshot(dplyr::select(df1, -expression))
+    expect_snapshot(select(df1, -expression))
     expect_snapshot(df1$expression[[1]])
   }
 )
@@ -80,20 +77,19 @@ test_that(
   code = {
     # subtitle
     set.seed(123)
-    df1 <-
-      two_sample_test(
-        type = "r",
-        data = dplyr::filter(ggplot2::msleep, vore %in% c("carni", "herbi")),
-        x = "vore",
-        y = "brainwt",
-        paired = FALSE,
-        conf.level = 0.90,
-        k = 4
-      )
+    df1 <- two_sample_test(
+      type = "r",
+      data = filter(ggplot2::msleep, vore %in% c("carni", "herbi")),
+      x = vore,
+      y = brainwt,
+      paired = FALSE,
+      conf.level = 0.90,
+      k = 4
+    )
 
     # testing all details
     set.seed(123)
-    expect_snapshot(dplyr::select(df1, -expression))
+    expect_snapshot(select(df1, -expression))
     expect_snapshot(df1$expression[[1]])
   }
 )
@@ -131,30 +127,28 @@ test_that(
         45L
       ), class = "data.frame")
 
-    df <- dplyr::filter(df, condition %in% c(1, 5))
+    df <- filter(df, condition %in% c(1, 5))
 
     # incorrect
     set.seed(123)
-    expr1 <-
-      two_sample_test(
-        type = "r",
-        data = df,
-        x = condition,
-        y = score,
-        subject.id = id,
-        paired = TRUE
-      )
+    expr1 <- two_sample_test(
+      type = "r",
+      data = df,
+      x = condition,
+      y = score,
+      subject.id = id,
+      paired = TRUE
+    )
 
     # correct
     set.seed(123)
-    expr2 <-
-      two_sample_test(
-        type = "r",
-        data = dplyr::arrange(df, id),
-        x = condition,
-        y = score,
-        paired = TRUE
-      )
+    expr2 <- two_sample_test(
+      type = "r",
+      data = arrange(df, id),
+      x = condition,
+      y = score,
+      paired = TRUE
+    )
 
     expect_equal(expr1, expr2)
   }
